import { searchFilesInDirectory } from './searchFilesInDirectory.mjs';
import { isFileOrFolderExists } from '../../util/isFileOrFolderExists.mjs';
import { parseJSON } from '../../util/parseJSON.mjs';
import { readFile } from '../../util/readFile.mjs';

async function getTestData(templateConfig, testFunction) {
    const result = testFunction.length === 0
        ? await testFunction()
        : await testFunction(templateConfig);
    const allFiles = await searchFilesInDirectory({
        directoryPath: templateConfig.projectCatalog,
        excludedFileNames: ['.DS_Store'],
        excludedPhrases: ['.backup'],
    });
    let repositoryMapFileConfigContent = null;
    if (templateConfig.repositoryMapFilePath) {
        try {
            const bufferData = await readFile(templateConfig.repositoryMapFilePath);
            repositoryMapFileConfigContent = await parseJSON(bufferData.toString());
        }
        catch (error) {
            console.error('Error reading or parsing repository map file:', error);
        }
    }
    return {
        ...result,
        allFiles,
        repositoryMapFileConfigContent,
    };
}
async function getProjectTestData(config, testFunction) {
    const result = testFunction.length === 0
        ? await testFunction()
        : await testFunction(config);
    const allFiles = await searchFilesInDirectory({
        directoryPath: config.projectCatalog,
        excludedFileNames: ['.DS_Store'],
        excludedPhrases: ['.backup'],
        excludeFolders: ['node_modules'],
    });
    let sumConfigFileContent = null;
    let sumFileMapConfigContent = null;
    if (await isFileOrFolderExists({ isDebug: config.isDebug, filePath: config.sumConfigFilePath })) {
        try {
            const bufferData = await readFile(config.sumConfigFilePath);
            sumConfigFileContent = await parseJSON(bufferData.toString());
        }
        catch (error) {
            console.error('Error reading or parsing repository map file:', error);
        }
    }
    if (await isFileOrFolderExists({ isDebug: config.isDebug, filePath: config.sumFileMapConfig })) {
        try {
            const bufferData = await readFile(config.sumFileMapConfig);
            sumFileMapConfigContent = await parseJSON(bufferData.toString());
        }
        catch (error) {
            console.error('Error reading or parsing repository map file:', error);
        }
    }
    return {
        ...result,
        allFiles,
        sumConfigFileContent,
        sumFileMapConfigContent,
    };
}

export { getProjectTestData, getTestData };
