import { cleanUpSinglePath } from './cleanForTests.mjs';
import { createFile } from '../../util/createFile.mjs';
import { createPath } from '../../util/createPath.mjs';
import { deletePath } from '../../util/deletePath.mjs';

const setupTestFiles = async (filesToCreate, isDebug) => {
    for (const file of filesToCreate) {
        await createFile({
            filePath: file.filePath,
            content: file.content ?? `{path: ${file.filePath}}`,
            options: file.options,
            isDebug,
        });
    }
};
const getCleanupPath = (type, folder, step) => {
    let path = type === 'test' ? `./test/${folder}` : `./mock/${folder}`;
    if (step === 'bumpVersion') {
        path = type === 'test' ? `./test/${folder}` : `./mock/${folder}`;
    }
    else if (step === 'cleanUpTemplate') {
        path = type === 'test' ? `./test/${folder}` : `./mock/${folder}`;
    }
    else if (step === 'scanProjectFolder') {
        path = type === 'test' ? `./test/${folder}` : `./mock/${folder}`;
    }
    else if (step === 'prepareFileList') {
        path = type === 'test' ? `./test/${folder}` : `./mock/${folder}`;
    }
    else if (step === 'updateTemplateConfig') {
        path = type === 'test' ? `./test/${folder}` : `./mock/${folder}`;
    }
    else if (step === 'formatJsonWithPrettier') {
        path = type === 'test' ? `./test/${folder}` : `./mock/${folder}`;
    }
    else if (step === 'buildFromConfig') {
        path = type === 'test' ? `./test/${folder}` : `./mock/${folder}`;
    }
    return path;
};
const cleanUpTemplateCatalog = async (type, step, templateCase = 'templateCatalog') => {
    let projectCatalog;
    if (templateCase === 'templateCatalog') {
        projectCatalog = 'mockTemplate';
    }
    else if (templateCase === 'mockTemplateWithImage') {
        projectCatalog = 'mockTemplateWithImage';
    }
    else if (templateCase === 'mockTemplateWithImageWithConfig') {
        projectCatalog = 'mockTemplateWithImageWithConfig';
    }
    else {
        projectCatalog = 'mockTemplateUpdate';
    }
    let folder = `${projectCatalog}/templateCatalog`;
    if (type === 'test') {
        folder = folder.replace('/templateCatalog', '');
        await cleanUpSinglePath({
            path: `./test/${folder}`,
            isDebug: true,
        });
        return;
    }
    const folderNodeModule = `${projectCatalog}/node_modules`;
    const folderTools = `${projectCatalog}/tools`;
    const pathTemplateCatalog = getCleanupPath(type, folder, step);
    const pathNodeModules = getCleanupPath(type, folderNodeModule, step);
    const pathTools = getCleanupPath(type, folderTools, step);
    await cleanUpSinglePath({
        path: pathTemplateCatalog,
        isDebug: true,
    });
    await cleanUpSinglePath({
        path: pathNodeModules,
        isDebug: true,
    });
    await cleanUpSinglePath({
        path: pathTools,
        isDebug: true,
    });
};
const cleanUpProjectCatalog = async (type, step, folderCase = 'mockProject') => {
    const rootPath = getCleanupPath(type, folderCase, step);
    let sumPath = '';
    if (folderCase === 'mockProject' || folderCase === 'mockProjectWithImage') {
        sumPath = createPath([rootPath, '.sum']);
    }
    if (folderCase === 'microProject') {
        sumPath = createPath([rootPath]);
    }
    await deletePath(createPath([rootPath, '.sum.config.json']), true);
    await deletePath(createPath([rootPath, '.sumignore']), true);
    await cleanUpSinglePath({
        path: sumPath !== '' ? sumPath : rootPath,
        isDebug: true,
    });
};

export { cleanUpProjectCatalog, cleanUpTemplateCatalog, setupTestFiles };
