import { updateDetailsFileMapConfig2 } from './updateFileMapConfig.mjs';
import { createPath } from '../util/createPath.mjs';
import { deletePath } from '../util/deletePath.mjs';
import { formatSum } from '../util/formatSum.mjs';
import { getIgnoredFilesFromConfig } from '../util/getIgnoredFilesFromConfig.mjs';
import { getRealFilePath } from '../util/getRealFilePath.mjs';
import { parseJSON } from '../util/parseJSON.mjs';
import { readFile } from '../util/readFile.mjs';

const cleanUpBeforeUpdate = async (config) => {
    let sumFileMapConfig = await readFile(config.sumFileMapConfig).then(async (bufferData) => parseJSON(bufferData.toString()));
    const fileToClean = [];
    const deletedPath = [];
    const ignoredFiles = await getIgnoredFilesFromConfig({ config, sumFileMapConfig });
    try {
        if (sumFileMapConfig.sumFileMap && sumFileMapConfig.fileMap) {
            const createdFileRealName = [];
            for (const SUMSuffixFileName of sumFileMapConfig.fileMap) {
                const realFilePath = getRealFilePath({ config, SUMSuffixFileName });
                const SUMKeySuffix = formatSum(SUMSuffixFileName, 'key');
                if (!createdFileRealName.includes([realFilePath, SUMKeySuffix]) && !ignoredFiles.includes(realFilePath)) {
                    createdFileRealName.push([realFilePath, SUMKeySuffix]);
                }
            }
            for (const [realFilePath, SUMKeySuffix] of createdFileRealName) {
                fileToClean.push(sumFileMapConfig.sumFileMap[realFilePath][SUMKeySuffix]);
                if (!fileToClean.includes(sumFileMapConfig.sumFileMap[realFilePath]['_'])) {
                    fileToClean.push(sumFileMapConfig.sumFileMap[realFilePath]['_']);
                }
            }
        }
        for (const sumFile of fileToClean) {
            await deletePath(createPath(sumFile.path), config.isDebug)
                .then(async () => {
                sumFileMapConfig = await updateDetailsFileMapConfig2({
                    sumFileMapConfig,
                    config,
                    operation: 'deleteFile',
                    SUMKeySuffix: sumFile.SUMKeySuffix,
                    // realFileName: sumFile.realFileName,
                    realFilePath: sumFile.realFilePath,
                });
                return sumFile.path;
            })
                .then((path) => {
                deletedPath.push(path);
            });
        }
        sumFileMapConfig = await updateDetailsFileMapConfig2({
            sumFileMapConfig,
            config,
            operation: 'removeFileMap',
        });
        return { config, deletedPath, sumFileMapConfig };
    }
    catch (err) {
        console.error('Error while downloading config from github', err);
        throw err;
    }
};

export { cleanUpBeforeUpdate };
