import { updateDetailsFileMapConfig2 } from './updateFileMapConfig.mjs';
import { createPath } from '../util/createPath.mjs';
import { deletePath } from '../util/deletePath.mjs';
import { getRealFilePath } from '../util/getRealFilePath.mjs';
import { parseJSON } from '../util/parseJSON.mjs';
import { readFile } from '../util/readFile.mjs';

const cleanUpFileTree = async (config) => {
    let sumFileMapConfig = await readFile(config.sumFileMapConfig).then(async (bufferData) => parseJSON(bufferData.toString()));
    try {
        if (sumFileMapConfig.createdFileMap.length > 0 &&
            sumFileMapConfig.fileMap.length > 0 &&
            sumFileMapConfig.sumFileMap &&
            Object.keys(sumFileMapConfig?.sumFileMap).length > 0) {
            const realFilesMap = new Map();
            sumFileMapConfig.fileMap.forEach((SUMSuffixFileName) => {
                const realFilePath = getRealFilePath({ config, SUMSuffixFileName });
                if (!realFilesMap.has(realFilePath)) {
                    realFilesMap.set(realFilePath, SUMSuffixFileName);
                }
            });
            const realFiles = Array.from(realFilesMap.keys());
            const temporarySumFileMap = sumFileMapConfig.sumFileMap;
            realFiles.forEach((file) => {
                delete temporarySumFileMap[file];
            });
            const fileToClean = [];
            for (const realNameFile in temporarySumFileMap) {
                for (const SUMKeySuffix in temporarySumFileMap[realNameFile]) {
                    fileToClean.push(temporarySumFileMap[realNameFile][SUMKeySuffix]);
                }
            }
            if (fileToClean.length > 0) {
                for (const sumFile of fileToClean) {
                    await deletePath(createPath(sumFile.path), config.isDebug).then(async () => {
                        sumFileMapConfig = await updateDetailsFileMapConfig2({
                            sumFileMapConfig,
                            config,
                            operation: 'deleteFile',
                            SUMKeySuffix: sumFile.SUMKeySuffix,
                            realFilePath: sumFile.realFilePath,
                        });
                    });
                }
            }
            else {
                console.log('no file has been cleaned');
            }
        }
        return config;
    }
    catch (err) {
        console.error('Error while downloading config from github', err);
        throw err;
    }
};

export { cleanUpFileTree };
