import { setArgsTemplate } from '../args/argsTemplate.mjs';
import { defaultTemplateConfig } from './const.mjs';
import { createPath } from '../../util/createPath.mjs';

const regenerateTemplateConfig = (config) => {
    const regeneratedConfig = { ...config };
    if (regeneratedConfig.templateCatalogName) {
        regeneratedConfig.templateCatalogPath = createPath([
            regeneratedConfig.projectCatalog,
            regeneratedConfig.templateCatalogName,
        ]);
    }
    if (regeneratedConfig.projectCatalog && regeneratedConfig.templateCatalogName) {
        regeneratedConfig.repositoryMapFilePath = createPath([
            regeneratedConfig.projectCatalog,
            regeneratedConfig.templateCatalogName,
            regeneratedConfig.repositoryMapFileName,
        ]);
    }
    return regeneratedConfig;
};
const updateTemplateKeyConfig = (config, keyToUpdate) => {
    const keyName = Object.keys(keyToUpdate)[0];
    const value = keyToUpdate[keyName];
    const valueToUpdate = { [keyName]: value };
    const updatedConfig = { ...config, ...valueToUpdate };
    return regenerateTemplateConfig(updatedConfig);
};
const getTemplateConfig = (args) => {
    let config = { ...defaultTemplateConfig };
    const argsObject = setArgsTemplate(args);
    config = updateTemplateKeyConfig(config, {
        isDebug: argsObject.isDebug || config.isDebug,
    });
    config = updateTemplateKeyConfig(config, {
        projectCatalog: argsObject.projectCatalog || config.projectCatalog,
    });
    return regenerateTemplateConfig(config);
};

export { getTemplateConfig, regenerateTemplateConfig, updateTemplateKeyConfig };
