import { createCatalog } from '../util/createCatalog.mjs';
import { buildURL } from '../util/formatterRepositoryFileNameUrl.mjs';
import { isFileOrFolderExists } from '../util/isFileOrFolderExists.mjs';
import { wgetAsync } from '../util/wget.mjs';

const getRemoteContentToBuild = async ({ config, sumObject, relativePaths, type = 'string', }) => {
    try {
        const contentUrl = buildURL({
            baseURL: config.remoteRootRepositoryUrl,
            relativePaths: relativePaths?.length ? relativePaths : [sumObject?.SUMSuffixFileName || ''],
        });
        if (!(await isFileOrFolderExists({ isDebug: config.isDebug, filePath: config.temporaryFolder }))) {
            await createCatalog(config.temporaryFolder);
        }
        if (type === 'buffer') {
            const response = await fetch(contentUrl);
            const buffer = await response.arrayBuffer();
            return Buffer.from(buffer);
        }
        return await wgetAsync(contentUrl, config.temporaryFolder).then(async (remoteContent) => {
            return remoteContent;
        });
    }
    catch (err) {
        console.error('Error while downloading config from github', err);
        throw err;
    }
};

export { getRemoteContentToBuild };
