import { isBinaryFile as isBinaryFile_1 } from '../../../node_modules/isbinaryfile/lib/index.mjs';
import path__default from 'path';
import { createFile } from '../../util/createFile.mjs';
import { createPath } from '../../util/createPath.mjs';
import { debugFunction } from '../../util/debugFunction.mjs';
import { readFile } from '../../util/readFile.mjs';

const prepareFileList = async ({ templateConfig, templateFileList, }) => {
    debugFunction(templateConfig.isDebug, { templateConfig, templateFileList }, '[PrepareTemplate] prepareFileList');
    const rootPathFileList = [];
    const fileList = [];
    const redOnlyFileList = [];
    for (const filePath of templateFileList) {
        const templateFilePath = createPath([templateConfig.projectCatalog, filePath]);
        const content = await readFile(templateFilePath);
        if (await isBinaryFile_1(templateFilePath, content.length)) {
            redOnlyFileList.push(createPath([filePath]).replace('./', ''));
            continue;
        }
        const fileName = path__default.basename(filePath) + '-default.md';
        const fileDir = path__default.dirname(filePath);
        rootPathFileList.push(createPath([templateConfig.projectCatalog, filePath]));
        fileList.push(createPath([templateConfig.templateCatalogName, filePath + '-default.md']));
        debugFunction(templateConfig.isDebug, { content }, `[PrepareTemplate] readed Content from file ${templateFilePath}`);
        await createFile({
            filePath: createPath([templateConfig.templateCatalogPath, fileDir, fileName]),
            content,
            isDebug: templateConfig.isDebug,
            options: {
                overwriteFile: true,
            },
        });
    }
    debugFunction(templateConfig.isDebug, { templateConfig, fileList, templateFileList, rootPathFileList }, '[PrepareTemplate] END prepareTemplateFile');
    return { templateConfig, templateFileList, fileList, rootPathFileList, redOnlyFileList };
};

export { prepareFileList };
