import path__default from 'path';
import { searchFilesInDirectory } from '../__tests__/searchFilesInDirectory.mjs';
import { createPath } from '../../util/createPath.mjs';
import { debugFunction } from '../../util/debugFunction.mjs';
import { gitignoreToGlobRules } from '../../util/gitignoreToGlobRules/gitignoreToGlobRules.mjs';

const scanProjectFolder = async (templateConfig) => {
    debugFunction(templateConfig.isDebug, { templateConfig }, '[PrepareTemplate - scanProjectFolder START]');
    const globRules = await gitignoreToGlobRules({
        prefix: createPath(templateConfig.projectCatalog) + '/',
        gitignorePath: createPath([templateConfig.projectCatalog, '.gitignore']),
    });
    const excludePaths = [
        ...globRules,
        createPath([templateConfig.projectCatalog, 'test/']),
        createPath([templateConfig.projectCatalog, templateConfig.templateCatalogName]),
    ];
    return searchFilesInDirectory({
        directoryPath: templateConfig.projectCatalog,
        excludePaths: excludePaths,
        excludedFileNames: [createPath(templateConfig.repositoryMapFileName), '.DS_Store'],
        excludedPhrases: ['.backup'],
    })
        .then((fileList) => {
        debugFunction(templateConfig.isDebug, { templateConfig, fileList }, '[PrepareTemplate - searchFilesInDirectory - START]');
        const filteredFiles = fileList.map((file) => {
            const relativePath = file.replace(templateConfig.projectCatalog, '');
            const normalizedPath = path__default.normalize(relativePath).replace(/^[/\\]+/, '');
            return './' + normalizedPath.replace(/\\/g, '/');
        });
        debugFunction(templateConfig.isDebug, { templateConfig, fileList, filteredFiles }, '[PrepareTemplate - searchFilesInDirectory - END]');
        debugFunction(templateConfig.isDebug, { templateConfig }, '[PrepareTemplate - scanProjectFolder END]');
        return { templateConfig, templateFileList: filteredFiles };
    })
        .catch((error) => {
        console.error('An error occurred:', error);
        return { templateConfig, templateFileList: [] };
    });
};

export { scanProjectFolder };
