import { updateDetailsFileMapConfig2 } from './updateFileMapConfig.mjs';
import { createPath } from '../util/createPath.mjs';
import { debugFunction } from '../util/debugFunction.mjs';
import { formatSum } from '../util/formatSum.mjs';
import { isFileOrFolderExists } from '../util/isFileOrFolderExists.mjs';
import { parseJSON } from '../util/parseJSON.mjs';
import { readFile } from '../util/readFile.mjs';

async function scanExtraFile(config) {
    debugFunction(config.isDebug, 'start', '[INIT] scanExtraFile');
    let sumFileMapConfig = await readFile(config.sumFileMapConfig).then(async (bufferData) => parseJSON(bufferData.toString()));
    if (sumFileMapConfig.sumFileMap) {
        for (const SUMKeySuffix of config.availableSUMKeySuffix) {
            if (SUMKeySuffix === 'defaultFile') {
                continue;
            }
            for (const [realFilePath] of Object.entries(sumFileMapConfig.sumFileMap || {})) {
                const sumSuffix = formatSum(SUMKeySuffix, 'suffix');
                const SUMSuffixFilePath = createPath([config.sumCatalog, config.templateCatalogName, realFilePath + sumSuffix]);
                if (await isFileOrFolderExists({ isDebug: config.isDebug, filePath: SUMSuffixFilePath })) {
                    const SUMSuffixFileName = createPath([realFilePath + sumSuffix]);
                    sumFileMapConfig = await updateDetailsFileMapConfig2({
                        sumFileMapConfig,
                        config,
                        operation: 'addConfigSuffixFile',
                        SUMKeySuffix,
                        SUMSuffixFileName,
                        isCreated: true,
                        path: SUMSuffixFilePath,
                        realFilePath,
                        realPath: createPath([config.projectCatalog, realFilePath]),
                        templateVersion: sumFileMapConfig.templateVersion,
                    });
                }
            }
        }
    }
    debugFunction(config.isDebug, config, '[INIT] scanExtraFile - end');
    return { config, sumFileMapConfig };
}

export { scanExtraFile };
