#!/usr/bin/env node
import minimist from '../node_modules/minimist/index.mjs';
import { cleanUpSinglePath } from './feature/__tests__/cleanForTests.mjs';
import { deletePath } from './util/deletePath.mjs';
import { buildFromConfig } from './feature/buildFromConfig.mjs';
import { cleanUp } from './feature/cleanUp.mjs';
import { getConfig } from './feature/config/defaultConfig.mjs';
import { createConfigFile } from './feature/createConfigFile.mjs';
import { downloadConfig } from './feature/downloadConfig.mjs';
import { prepareBaseSumFileMap } from './feature/prepareBaseFile.mjs';
import { scanExtraFile } from './feature/scanExtraFile.mjs';
import { debugFunction } from './util/debugFunction.mjs';
import { isFileOrFolderExists } from './util/isFileOrFolderExists.mjs';

const init = async (args) => {
    const config = await getConfig(args);
    if ((await isFileOrFolderExists({ isDebug: config.isDebug, filePath: config.sumFileMapConfig })) &&
        (await isFileOrFolderExists({ isDebug: config.isDebug, filePath: config.sumConfigFilePath }))) {
        if (process.env.SDEBUG !== 'true') {
            throw new Error('Config file exists, use build script or update');
        }
    }
    if (process.env.SDEBUG === 'true') {
        await deletePath(config.sumConfigFilePath, true);
        await cleanUpSinglePath({
            path: config.sumCatalog,
            isDebug: config.isDebug,
        });
    }
    debugFunction(config.isDebug, '=== Start SUM INIT ===', '[INIT]');
    return config;
};
const args = minimist(process.argv.slice(2));
let finalConfig = {
    isDebug: false,
};
init(args)
    .then((config) => {
    finalConfig = config;
    return createConfigFile(config);
})
    .then(({ config }) => {
    finalConfig = config;
    return downloadConfig(config);
})
    .then(({ config }) => {
    finalConfig = config;
    return prepareBaseSumFileMap(config);
})
    .then(({ config }) => {
    finalConfig = config;
    return scanExtraFile(config);
})
    .then(({ config }) => {
    finalConfig = config;
    return buildFromConfig(config);
})
    .then(({ config }) => {
    finalConfig = config;
    return cleanUp(config);
})
    .finally(() => {
    debugFunction(finalConfig?.isDebug, { finalConfig }, '[INIT] final config');
    debugFunction(finalConfig?.isDebug, '=== final SUM INIT ===');
});

export { init };
