#!/usr/bin/env node
import minimist from '../node_modules/minimist/index.mjs';
import { setupTestFiles } from './feature/__tests__/prepareFileForTests.mjs';
import { createPath } from './util/createPath.mjs';
import { buildFromConfig } from './feature/buildFromConfig.mjs';
import { cleanUp } from './feature/cleanUp.mjs';
import { cleanUpBeforeUpdate } from './feature/cleanUpBeforeUpdate.mjs';
import { cleanUpFileTree } from './feature/cleanUpFileTree.mjs';
import { getConfig } from './feature/config/defaultConfig.mjs';
import { downloadConfig } from './feature/downloadConfig.mjs';
import { prepareBaseSumFileMap } from './feature/prepareBaseFile.mjs';
import { scanExtraFile } from './feature/scanExtraFile.mjs';
import { createCatalog } from './util/createCatalog.mjs';
import { debugFunction } from './util/debugFunction.mjs';

const update = async (args) => {
    const config = await getConfig(args);
    if (!config.sumFileMapConfig) {
        throw new Error('Config file not exists, use init script');
    }
    if (process.env.SDEBUG == 'true') {
        const FileToCreate = [
            {
                filePath: createPath([config.projectCatalog, 'README.md']),
                content: '# mockTemplateToUpdate\n\nThis repository is used to test the s-prepare-template command.\n',
            },
            {
                filePath: createPath([config.projectCatalog, 'tsConfig.json']),
                content: '{\n  "compilerOptions": {\n    "lib": ["ES2022"]\n  },\n  "exclude": ["node_modules"]\n}',
            },
            {
                filePath: createPath([config.projectCatalog, 'yarn.lock']),
                content: '# THIS IS AN AUTOGENERATED FILE. DO NOT EDIT THIS FILE DIRECTLY.\n' +
                    '# yarn lockfile v1\n' +
                    '\n' +
                    'ajv@^5.1.0:\n' +
                    '  version "5.5.2"\n' +
                    '  resolved "https://registry.yarnpkg.com/ajv/-/ajv-5.5.2.tgz#73b5eeca3fab653e3d3f9422b341ad42205dc965"\n' +
                    '  integrity sha512-Ajr4IcMXq/2QmMkEmSvxqfLN5zGmJ92gHXAeOXq1OekoH2rfDNsgdDoL2f7QaRCy7G/E6TpxBVdRuNraMztGHw==',
            },
        ];
        setupTestFiles(FileToCreate, config.isDebug);
    }
    debugFunction(config.isDebug, '=== Start SUM UPDATE ===');
    return await createCatalog(config.temporaryFolder).then(() => {
        return { ...config };
    });
};
const args = minimist(process.argv.slice(2));
let finalConfig = {
    isDebug: false,
};
update(args)
    .then((config) => {
    finalConfig = config;
    return cleanUpBeforeUpdate(config);
})
    .then(({ config }) => {
    finalConfig = config;
    return downloadConfig(config);
})
    .then(({ config }) => {
    finalConfig = config;
    return cleanUpFileTree(config);
})
    .then((config) => {
    finalConfig = config;
    return prepareBaseSumFileMap(config);
})
    .then(({ config }) => {
    finalConfig = config;
    return scanExtraFile(config);
})
    .then(({ config }) => {
    finalConfig = config;
    return buildFromConfig(config);
})
    .then(({ config }) => {
    finalConfig = config;
    return cleanUp(config);
})
    .finally(() => {
    debugFunction(finalConfig?.isDebug, { finalConfig }, '[UPDATE] final config');
    debugFunction(finalConfig?.isDebug, '=== final SUM UPDATE ===');
});

export { update };
