import path__default from 'path';
import { createPath } from '../createPath.mjs';
import { readFile } from '../readFile.mjs';

async function gitignoreToGlobRules({ prefix, gitignorePath, }) {
    try {
        const content = await readFile(gitignorePath).then((data) => data.toString());
        const rules = content
            .split('\n')
            .map((line) => line.trim())
            .filter((line) => line && !line.startsWith('#'));
        const globPatterns = rules.map((rule) => {
            if (rule.startsWith('!')) {
                rule = `!./${path__default.join(prefix, rule.slice(1))}`;
            }
            else {
                rule = `./${createPath([path__default.join(prefix, rule)])}`;
            }
            return rule.replace(/\/\//g, '/');
        });
        return globPatterns;
    }
    catch (error) {
        console.error('Error processing .gitignore file:', error);
        return [];
    }
}

export { gitignoreToGlobRules };
