import fs from 'fs';
import { promisify } from 'util';
import { isFileOrFolderExists } from './isFileOrFolderExists.mjs';

async function toCreateFile({ filePath, content, options = { overwriteFile: true, backupFile: true }, isDebug = false, }) {
    const { overwriteFile, backupFile } = options;
    const readFile = promisify(fs.readFile);
    const writeFile = promisify(fs.writeFile);
    try {
        const fileExists = await isFileOrFolderExists({ isDebug, filePath });
        if (backupFile && fileExists) {
            const existingContent = await readFile(filePath, 'utf-8');
            if (existingContent !== content.toString()) {
                const backupFilePath = filePath + '.backup';
                await writeFile(backupFilePath, existingContent);
            }
        }
        if (((await isFileOrFolderExists({ isDebug, filePath })) && overwriteFile) ||
            !(await isFileOrFolderExists({ isDebug, filePath }))) {
            // If overwriteFile is true or backupFile is false, overwrite the file or create a new one
            await writeFile(filePath, content);
        }
    }
    catch (error) {
        if (isDebug) {
            console.error(`Error creating file ${filePath}: ${error.message}`);
        }
        throw error; // You might want to handle the error differently based on your application's needs
    }
}

export { toCreateFile };
